package com.ruoyi.care.mapper;

import java.util.List;
import com.ruoyi.care.domain.CareNurseClocks;

/**
 * 护理任务打卡Mapper接口
 * 
 * @author qy
 * @date 2024-11-26
 */
public interface CareNurseClocksMapper 
{
    /**
     * 查询护理任务打卡
     * 
     * @param clockId 护理任务打卡主键
     * @return 护理任务打卡
     */
    public CareNurseClocks selectCareNurseClocksByClockId(Long clockId);

    /**
     * 查询护理任务打卡列表
     * 
     * @param careNurseClocks 护理任务打卡
     * @return 护理任务打卡集合
     */
    public List<CareNurseClocks> selectCareNurseClocksList(CareNurseClocks careNurseClocks);

    /**
     * 新增护理任务打卡
     * 
     * @param careNurseClocks 护理任务打卡
     * @return 结果
     */
    public int insertCareNurseClocks(CareNurseClocks careNurseClocks);

    /**
     * 修改护理任务打卡
     * 
     * @param careNurseClocks 护理任务打卡
     * @return 结果
     */
    public int updateCareNurseClocks(CareNurseClocks careNurseClocks);

    /**
     * 删除护理任务打卡
     * 
     * @param clockId 护理任务打卡主键
     * @return 结果
     */
    public int deleteCareNurseClocksByClockId(Long clockId);

    /**
     * 批量删除护理任务打卡
     * 
     * @param clockIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCareNurseClocksByClockIds(Long[] clockIds);
}
